@@ -1,5 +1,5 @@
 /*****************************************************************************
- *  $Id: libedac.c 75 2008-01-25 19:39:05Z grondo $
+ *  $Id: libedac.c 93 2008-08-08 18:23:35Z grondo $
  *****************************************************************************
  *  Copyright (C) 2005-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -208,13 +208,13 @@ int edac_handle_reset (edac_handle *edac)
 
 int edac_error_totals (edac_handle *edac, struct edac_totals *tot)
 {
-    memset (tot, 0, sizeof (*tot));
-
     if ((edac == NULL) || (tot == NULL)) {
         errno = EINVAL;
         return (-1);
     }
 
+    memset (tot, 0, sizeof (*tot));
+
     if (!edac->totals_valid)  {
         if (edac_totals_refresh (edac) < 0) {
             return (-1);
@@ -312,6 +312,14 @@ static inline void edac_dlist_reset (struct dlist *l)
     dlist_next (l);
 }
 
+static inline void remove_newline (char *str)
+{
+    int len = strlen (str);
+
+    if (len && str[len - 1] == '\n')
+        str[len - 1] = '\0';
+}
+
 static int
 edac_channel_refresh (struct edac_csrow *csrow, int id)
 {
@@ -336,6 +344,8 @@ edac_channel_refresh (struct edac_csrow *csrow, int id)
         chan->dimm_label_valid = 1;
     }
 
+    remove_newline (chan->dimm_label);
+
     chan->valid = 1;
     return (0);
 }
